`r lifecycle::badge("deprecated")`
This function has been deprecated in favour of the native
plot_brain() renderer.
Use schaefer_surf() to obtain a surface atlas and
plot_brain() for visualisation.
`r lifecycle::badge("deprecated")`
This function has been deprecated in favour of the native
plot_brain() renderer.
Use schaefer_surf() to obtain a surface atlas and
plot_brain() for visualisation.