Skip to contents

Enumerate the atlases currently registered in the neuroatlas dispatch registry. Useful for discovery from scripts, vignettes, and Shiny apps.

Usage

list_atlases()

Value

A tibble with one row per registered atlas and columns `id`, `label`, `family`, `representation`, `default_space`, and a comma-joined `aliases` string.

See also

[get_atlas()] to load an atlas by id.

Examples

list_atlases()
#> # A tibble: 17 × 6
#>    id                         label  family representation default_space aliases
#>    <chr>                      <chr>  <chr>  <chr>          <chr>         <chr>  
#>  1 aseg                       FreeS… aseg   volume         MNI152NLin6A… "frees…
#>  2 brainnetome                Brain… brain… volume         MNI152        "bna,b…
#>  3 glasser                    Glass… glass… volume         MNI152NLin20… "hcp-m…
#>  4 glasser_surf               Glass… glass… surface        fsaverage     ""     
#>  5 harvard_oxford             Harva… harva… volume         MNI152NLin6A… "ho,ha…
#>  6 harvard_oxford_cortical    Harva… harva… volume         MNI152NLin6A… "ho_co…
#>  7 harvard_oxford_subcortical Harva… harva… volume         MNI152NLin6A… "ho_su…
#>  8 hcpex                      HCPex… hcpex  volume         MNI152NLin20… "hcpex…
#>  9 hippocampus                Hippo… olsen  derived        MNI152_custom "hipp" 
#> 10 julich_brain               Julic… julic… volume         MNI152        "jueli…
#> 11 olsen_mtl                  Olsen… olsen  volume         MNI152_custom "olsen…
#> 12 schaefer                   Schae… schae… volume         MNI152NLin6A… "schae…
#> 13 schaefer_surf              Schae… schae… surface        fsaverage6    "schae…
#> 14 subcortical                Subco… subco… volume         MNI152NLin6A… "atlas…
#> 15 visfatlas                  visfA… visfa… volume         MNI152        "rosen…
#> 16 visual                     Early… visual derived        MNI152        "early…
#> 17 wang                       Wang … wang   surface        fsaverage     "wang2…