Skip to contents

Returns the path to the TemplateFlow cache directory. With the pure R templateflow package, this is the TEMPLATEFLOW_HOME directory.

Usage

show_templateflow_cache_path()

Value

A character string representing the path to the TemplateFlow cache directory.

Examples

cat("TemplateFlow cache is at:", show_templateflow_cache_path(), "\n")
#> TemplateFlow cache is at: /home/runner/.cache/R/neuroatlas/templateflow