Wraps [.neuroatlas_download()] but returns a status list instead of throwing, so callers can implement fallback strategies while still having access to the full error condition (rather than a silent `NULL`).
Wraps [.neuroatlas_download()] but returns a status list instead of throwing, so callers can implement fallback strategies while still having access to the full error condition (rather than a silent `NULL`).