R/fsaverage.R
fsaverage.Rd
A list including left and right hemispheres for the orig, white, inflated, and pial surfaces.
data(fsaverage)
A named list with elements lh and rh, each containing surface geometry objects for orig, white, inflated, and pial surfaces.
lh
rh
# \donttest{ data(fsaverage) names(fsaverage) #> [1] "lh_inflated" "lh_orig" "lh_pial" "lh_white" "rh_inflated" #> [6] "rh_pial" "rh_white" # }