`r lifecycle::badge("deprecated")`
This function has been deprecated. Use
plot_brain(glasser_surf(), vals = ...) instead for interactive
cortical surface visualisation.
Arguments
- vals
A data frame containing values to plot, must include columns:
label: character, matching ggseg Glasser atlas labels
value: numeric, values to visualize for each region
If NULL (default), all regions will be assigned a value of 1
- value_col
Character string specifying the name of the column in vals containing the values to plot. Defaults to "value"
- position
Character string specifying layout type.